Rename the dungeons.
[rogue-pphs.git] / command.c
index eaa3648..584ba8a 100644 (file)
--- a/command.c
+++ b/command.c
@@ -3,7 +3,7 @@
  *\r
  * @(#)command.c       3.45 (Berkeley) 6/15/81\r
  *\r
* Rogue: Exploring the Dungeons of Doom\r
  * Copyright (C) 1980, 1981 Michael Toy, Ken Arnold and Glenn Wichman\r
  * All rights reserved.\r
  *\r
@@ -193,7 +193,7 @@ command()
                    {\r
                        if (wizard = passwd())\r
                        {\r
-                           msg("You are suddenly as smart as Ken Arnold in dungeon #%d", dnum);\r
+                           msg("You are suddenly as smart as Ken Arnold in cavern #%d", dnum);\r
                            wizard = TRUE;\r
                            waswizard = TRUE;\r
                        }\r
@@ -3,7 +3,7 @@
  * @(#)command.c       3.45 (Berkeley) 6/15/81\r
  *\r
- * Rogue: Exploring the Dungeons of Doom\r
+ * Rogue: Exploring the Cavern of Cuties\r
  * Copyright (C) 1980, 1981 Michael Toy, Ken Arnold and Glenn Wichman\r
  * All rights reserved.\r